from helga.plugins import command, ResponseNotReady
from requests import get
from twisted.internet import reactor

def bipol_async(client, channel, args):
    response = get('http://bipolasaservice.herokuapp.com/bipol')
    client.msg(channel, response.text)

@command('bipol', help='listen to what he has to say')
def bipol(client, channel, nick, message, cmd, args):
    reactor.callLater(0, bipol_async, client, channel, args)
    raise ResponseNotReady




from setuptools import setup, find_packages

setup(
    name='bipol',
    version='0.0.5',
    description='A bipol plugin',
    license='MIT',
    author='Patrick Sanders',
    author_email='mail@patricksanders.net',
    url='https://github.com/patricksanders/bipol',
    install_requires=[
        'requests',
        'helga',
    ],
    packages=find_packages(),
    py_modules=['bipol'],
    include_package_data=True,
    zip_safe=True,
    classifiers=[
        'License :: OSI Approved :: MIT License',
    ],
    entry_points=dict(
        helga_plugins=[
            'bipol = bipol:bipol',
        ],
    ),
)
